==> biostime-openapi-sdk-1.2.1.RELEASE-sources.jar: global/hh/openapi/sdk/api/bean/merchant/MerchantSendCommunityReportXiaoUFailMsgReqBean.java <==
package global.hh.openapi.sdk.api.bean.merchant;

        import java.util.List;

/**
 * @description: 提供给小U，当小助手封号或者异常情况时，触发该接口
 * @author: 777771
 * @date: 2020-23-13 16:23:31
 */
public class MerchantSendCommunityReportXiaoUFailMsgReqBean {
    /**
     * 小U异常小助手Id
     */
    private String helperOldWxId;

    /**
     * 小U新小助手Id
     */
    private String helperNewWxId;

    /**
     * 小U新小助手状态 10 正常 14异常 20封号
     */
    private String helperNewStatus;

    /**
     * 小U旧小助手状态 10 正常 14异常 20封号
     */
    private String helperOldStatus;

    /**
     * 小U异常小助手微信昵称
     */
    private String helperOldWxName;

    /**
     * 小U新小助手微信昵称
     */
    private String helperNewWxName;

    /**
     * 小U异常小助手绑定用户微信ID列表
     */
    private List<String> bindingUserWxIdList;

    public MerchantSendCommunityReportXiaoUFailMsgReqBean(){
    }

    public MerchantSendCommunityReportXiaoUFailMsgReqBean(String helperOldWxId,String helperNewWxId,String helperNewStatus,String helperOldStatus,String helperOldWxName,String helperNewWxName,List<String> bindingUserWxIdList){
        this.helperOldWxId=helperOldWxId;
        this.helperNewWxId=helperNewWxId;
        this.helperNewStatus=helperNewStatus;
        this.helperOldStatus=helperOldStatus;
        this.helperOldWxName=helperOldWxName;
        this.helperNewWxName=helperNewWxName;
        this.bindingUserWxIdList=bindingUserWxIdList;
    }

    private String getHelperOldWxId() {
        return helperOldWxId;
    }

    private void setHelperOldWxId(String helperOldWxId) {
        this.helperOldWxId = helperOldWxId;
    }
    private String getHelperNewWxId() {
        return helperNewWxId;
    }

    private void setHelperNewWxId(String helperNewWxId) {
        this.helperNewWxId = helperNewWxId;
    }
    private String getHelperNewStatus() {
        return helperNewStatus;
    }

    private void setHelperNewStatus(String helperNewStatus) {
        this.helperNewStatus = helperNewStatus;
    }
    private String getHelperOldStatus() {
        return helperOldStatus;
    }

    private void setHelperOldStatus(String helperOldStatus) {
        this.helperOldStatus = helperOldStatus;
    }
    private String getHelperOldWxName() {
        return helperOldWxName;
    }

    private void setHelperOldWxName(String helperOldWxName) {
        this.helperOldWxName = helperOldWxName;
    }
    private String getHelperNewWxName() {
        return helperNewWxName;
    }

    private void setHelperNewWxName(String helperNewWxName) {
        this.helperNewWxName = helperNewWxName;
    }
    private List<String> getBindingUserWxIdList() {
        return bindingUserWxIdList;
    }

    private void setBindingUserWxIdList(List<String> bindingUserWxIdList) {
        this.bindingUserWxIdList = bindingUserWxIdList;
    }
}

==> biostime-openapi-sdk-1.5.9.2-RELEASE-sources.jar: global/hh/openapi/sdk/api/bean/merchant/MerchantSendCommunityReportXiaoUFailMsgReqBean.java <==
package global.hh.openapi.sdk.api.bean.merchant;

        import java.util.List;

/**
 * @description: 提供给小U，当小助手封号或者异常情况时，触发该接口
 * @author: 3742
 * @date: 2020-42-13 16:42:38
 */
public class MerchantSendCommunityReportXiaoUFailMsgReqBean {
    /**
     * 小U异常小助手Id
     */
    private String helperOldWxId;

    /**
     * 小U新小助手Id
     */
    private String helperNewWxId;

    /**
     * 小U新小助手状态 10 正常 14异常 20封号
     */
    private String helperNewStatus;

    /**
     * 小U旧小助手状态 10 正常 14异常 20封号
     */
    private String helperOldStatus;

    /**
     * 小U异常小助手微信昵称
     */
    private String helperOldWxName;

    /**
     * 小U新小助手微信昵称
     */
    private String helperNewWxName;

    /**
     * 小U异常小助手绑定用户微信ID列表
     */
    private List<String> bindingUserWxIdList;

    public MerchantSendCommunityReportXiaoUFailMsgReqBean(){
    }

    public MerchantSendCommunityReportXiaoUFailMsgReqBean(String helperOldWxId,String helperNewWxId,String helperNewStatus,String helperOldStatus,String helperOldWxName,String helperNewWxName,List<String> bindingUserWxIdList){
        this.helperOldWxId=helperOldWxId;
        this.helperNewWxId=helperNewWxId;
        this.helperNewStatus=helperNewStatus;
        this.helperOldStatus=helperOldStatus;
        this.helperOldWxName=helperOldWxName;
        this.helperNewWxName=helperNewWxName;
        this.bindingUserWxIdList=bindingUserWxIdList;
    }

    public String getHelperOldWxId() {
        return helperOldWxId;
    }

    public void setHelperOldWxId(String helperOldWxId) {
        this.helperOldWxId = helperOldWxId;
    }
    public String getHelperNewWxId() {
        return helperNewWxId;
    }

    public void setHelperNewWxId(String helperNewWxId) {
        this.helperNewWxId = helperNewWxId;
    }
    public String getHelperNewStatus() {
        return helperNewStatus;
    }

    public void setHelperNewStatus(String helperNewStatus) {
        this.helperNewStatus = helperNewStatus;
    }
    public String getHelperOldStatus() {
        return helperOldStatus;
    }

    public void setHelperOldStatus(String helperOldStatus) {
        this.helperOldStatus = helperOldStatus;
    }
    public String getHelperOldWxName() {
        return helperOldWxName;
    }

    public void setHelperOldWxName(String helperOldWxName) {
        this.helperOldWxName = helperOldWxName;
    }
    public String getHelperNewWxName() {
        return helperNewWxName;
    }

    public void setHelperNewWxName(String helperNewWxName) {
        this.helperNewWxName = helperNewWxName;
    }
    public List<String> getBindingUserWxIdList() {
        return bindingUserWxIdList;
    }

    public void setBindingUserWxIdList(List<String> bindingUserWxIdList) {
        this.bindingUserWxIdList = bindingUserWxIdList;
    }
}
